<?php
/**
* ǥ륤󥿥ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
interface IModel extends IObject
{
	/**
	 * ǥID
	 */
	public function getModelID();

	/**
	 * եɰ
	 */
	public function getFieldList();

	/**
	 * եɤ¸ߤ뤫
	 */
	public function fieldExists( String $field_name );

	/*
	 *   Υơ
	 */
	public function getAnnotation( String $field, String $type );

	/*
	 *   Υơͤ
	 */
	public function getAnnotationValue( String $field, String $type, $defaultValue = NULL );

}
return __FILE__;
